@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015 Stuart Howarth <showarth@marxoft.co.uk>
+ * Copyright (C) 2016 Stuart Howarth <showarth@marxoft.co.uk>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
@@ -19,6 +19,7 @@
 #include <QDeclarativeInfo>
 #include <QMenu>
 #include <QCursor>
+#include <QEvent>
 
 class QchMenuPrivate
 {
@@ -396,6 +397,14 @@ void QchMenu::componentComplete() {
     d->init();
 }
 
+bool QchMenu::event(QEvent *e) {    
+    if (e->type() == QEvent::ParentChange) {
+        emit parentChanged();
+    }
+    
+    return QObject::event(e);
+}
+
 /*!
     \fn void Menu::aboutToHide()
     \brief Emitted when the menu is about to be hidden.
